scoretools.Voice
================

.. autoclass:: abjad.tools.scoretools.Voice.Voice

Lineage
-------

.. graphviz::

   digraph InheritanceGraph {
       graph [background=transparent,
           color=lightslategrey,
           fontname=Arial,
           outputorder=edgesfirst,
           overlap=prism,
           penwidth=2,
           rankdir=LR,
           root="__builtin__.object",
           splines=spline,
           style="dotted, rounded"];
       node [colorscheme=pastel19,
           fontname=Arial,
           fontsize=12,
           penwidth=2,
           style="filled, rounded"];
       edge [color=lightsteelblue2,
           penwidth=2];
       subgraph cluster___builtin__ {
           graph [label=__builtin__];
           "__builtin__.object" [color=1,
               group=0,
               label=object,
               shape=box];
       }
       subgraph cluster_abctools {
           graph [label=abctools];
           "abctools.AbjadObject" [color=2,
               group=1,
               label=AbjadObject,
               shape=box];
           "abctools.AbjadObject.AbstractBase" [color=2,
               group=1,
               label=AbstractBase,
               shape=box];
           "abctools.AbjadObject.AbstractBase" -> "abctools.AbjadObject";
       }
       subgraph cluster_scoretools {
           graph [label=scoretools];
           "scoretools.Component" [color=3,
               group=2,
               label=Component,
               shape=oval,
               style=bold];
           "scoretools.Container" [color=3,
               group=2,
               label=Container,
               shape=box];
           "scoretools.Context" [color=3,
               group=2,
               label=Context,
               shape=box];
           "scoretools.Voice" [color=black,
               fontcolor=white,
               group=2,
               label=<<B>Voice</B>>,
               shape=box,
               style="filled, rounded"];
           "scoretools.Component" -> "scoretools.Container";
           "scoretools.Container" -> "scoretools.Context";
           "scoretools.Context" -> "scoretools.Voice";
       }
       "__builtin__.object" -> "abctools.AbjadObject.AbstractBase";
       "abctools.AbjadObject" -> "scoretools.Component";
   }

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.scoretools.Voice.Voice.append
      ~abjad.tools.scoretools.Voice.Voice.consists_commands
      ~abjad.tools.scoretools.Voice.Voice.context_name
      ~abjad.tools.scoretools.Voice.Voice.extend
      ~abjad.tools.scoretools.Voice.Voice.index
      ~abjad.tools.scoretools.Voice.Voice.insert
      ~abjad.tools.scoretools.Voice.Voice.is_nonsemantic
      ~abjad.tools.scoretools.Voice.Voice.is_semantic
      ~abjad.tools.scoretools.Voice.Voice.is_simultaneous
      ~abjad.tools.scoretools.Voice.Voice.name
      ~abjad.tools.scoretools.Voice.Voice.pop
      ~abjad.tools.scoretools.Voice.Voice.remove
      ~abjad.tools.scoretools.Voice.Voice.remove_commands
      ~abjad.tools.scoretools.Voice.Voice.reverse
      ~abjad.tools.scoretools.Voice.Voice.select_leaves
      ~abjad.tools.scoretools.Voice.Voice.__contains__
      ~abjad.tools.scoretools.Voice.Voice.__copy__
      ~abjad.tools.scoretools.Voice.Voice.__delitem__
      ~abjad.tools.scoretools.Voice.Voice.__eq__
      ~abjad.tools.scoretools.Voice.Voice.__format__
      ~abjad.tools.scoretools.Voice.Voice.__getitem__
      ~abjad.tools.scoretools.Voice.Voice.__graph__
      ~abjad.tools.scoretools.Voice.Voice.__hash__
      ~abjad.tools.scoretools.Voice.Voice.__illustrate__
      ~abjad.tools.scoretools.Voice.Voice.__len__
      ~abjad.tools.scoretools.Voice.Voice.__mul__
      ~abjad.tools.scoretools.Voice.Voice.__ne__
      ~abjad.tools.scoretools.Voice.Voice.__repr__
      ~abjad.tools.scoretools.Voice.Voice.__rmul__
      ~abjad.tools.scoretools.Voice.Voice.__setitem__

Bases
-----

- :py:class:`scoretools.Context <abjad.tools.scoretools.Context.Context>`

- :py:class:`scoretools.Container <abjad.tools.scoretools.Container.Container>`

- :py:class:`scoretools.Component <abjad.tools.scoretools.Component.Component>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.scoretools.Voice.Voice.consists_commands
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Voice.Voice.is_semantic
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Voice.Voice.remove_commands
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.scoretools.Voice.Voice.context_name
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Voice.Voice.is_nonsemantic
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Voice.Voice.is_simultaneous
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Voice.Voice.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.scoretools.Voice.Voice.append
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.extend
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.index
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.insert
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.pop
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.remove
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.reverse
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.select_leaves
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.scoretools.Voice.Voice.__contains__
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.__copy__
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.__delitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.__eq__
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.__format__
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.__getitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.__graph__
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.__hash__
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.__illustrate__
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.__len__
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.__mul__
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.__ne__
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.__repr__
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.__rmul__
   :noindex:

.. automethod:: abjad.tools.scoretools.Voice.Voice.__setitem__
   :noindex:
